==> testik_generator-0.0.1.tar.gz: lib/src/testik_generator.dart <==
import 'dart:async';
import 'package:analyzer/dart/element/element.dart';
import 'package:build/src/builder/build_step.dart';
import 'package:source_gen/source_gen.dart';

import 'package:testik/testik.dart';
import 'package:testik_generator/src/template/params.dart';

import 'template/testik.dart';

class TestikDataGenerator extends GeneratorForAnnotation<Data> {
  @override
  FutureOr<String> generateForAnnotatedElement(
      Element element, ConstantReader annotation, BuildStep buildStep) {

        if(!(element is ClassElement)) {
          throw Exception("Only class element are supported");
        }

        var classElement = element as ClassElement;

        if(classElement.constructors.length != 2) {
           throw Exception("Only single factory constructor is supported"); 
        }

        var constructorElement = classElement.constructors[1];

        if(!constructorElement.isFactory) {
           throw Exception("Only factory element is supported, found $constructorElement"); 
        }

        var parameters = constructorElement.parameters;

        var testikParams = <ParamTemplate>[];
        for(int i=0; i<parameters.length; i++) {
          var param = parameters[i];
          testikParams.add(ParamTemplate(param.type.displayName, param.name)); 
        }

        var testikClass = TestikTemplate(classElement.name, testikParams);
        var testikInitClass = TestikInitTemplate(classElement.name, testikParams);
        
        return testikClass.toString() + "\n\n" + testikInitClass.toString();

    
  }
}

==> testik_generator-0.0.2.tar.gz: lib/src/testik_generator.dart <==
import 'dart:async';
import 'package:analyzer/dart/element/element.dart';
import 'package:build/src/builder/build_step.dart';
import 'package:source_gen/source_gen.dart';

import 'package:testik/testik.dart';
import 'package:testik_generator/src/template/params.dart';

import 'template/testik.dart';

class TestikDataGenerator extends GeneratorForAnnotation<Data> {
  @override
  FutureOr<String> generateForAnnotatedElement(
      Element element, ConstantReader annotation, BuildStep buildStep) {

        if(!(element is ClassElement)) {
          throw Exception("Only class element are supported");
        }

        var classElement = element as ClassElement;

        if(classElement.constructors.length != 2) {
           throw Exception("Only single factory constructor is supported"); 
        }

        var constructorElement = classElement.constructors[1];

        if(!constructorElement.isFactory) {
           throw Exception("Only factory element is supported, found $constructorElement"); 
        }

        var parameters = constructorElement.parameters;

        var testikParams = <ParamTemplate>[];
        for(int i=0; i<parameters.length; i++) {
          var param = parameters[i];
  
          testikParams.add(ParamTemplate(param.isNamed, param.type.displayName, param.name)); 
        }


        var testikClass = TestikTemplate(classElement.name, testikParams);
        var testikInitClass = TestikInitTemplate(classElement.name, testikParams);
        
        return testikClass.toString() + "\n\n" + testikInitClass.toString();

    
  }
}
